@@ -1,7 +1,8 @@
 import time
 from typing import Any, Dict, List, Optional
 
-import kubernetes
+import kubernetes.config
+import kubernetes.watch
 from dagster import Field, In, Noneable, Nothing, OpExecutionContext, Permissive, StringSource, op
 from dagster._annotations import experimental
 from dagster._utils.merger import merge_dicts
@@ -207,6 +208,8 @@ def execute_k8s_job(
     if command:
         container_config["command"] = command
 
+    container_name = container_config.get("name", "dagster")
+
     op_container_context = K8sContainerContext(
         image_pull_policy=image_pull_policy,
         image_pull_secrets=image_pull_secrets,
@@ -315,7 +318,10 @@ def execute_k8s_job(
     api_client.wait_for_pod(pod_to_watch, namespace, wait_timeout=timeout, start_time=start_time)
 
     log_stream = watch.stream(
-        api_client.core_api.read_namespaced_pod_log, name=pod_to_watch, namespace=namespace
+        api_client.core_api.read_namespaced_pod_log,
+        name=pod_to_watch,
+        namespace=namespace,
+        container=container_name,
     )
 
     while True:
@@ -351,9 +357,6 @@ def k8s_job_op(context):
       - You want to run the rest of a Dagster job using a specific executor, and only a single
         op in k8s.
 
-    You can create your own op with the same implementation by calling the `execute_k8s_job` function
-    inside your own op.
-
     For example:
 
     .. literalinclude:: ../../../../../../python_modules/libraries/dagster-k8s/dagster_k8s_tests/unit_tests/test_example_k8s_job_op.py
@@ -361,6 +364,9 @@ def k8s_job_op(context):
       :end-before: end_marker
       :language: python
 
+    You can create your own op with the same implementation by calling the `execute_k8s_job` function
+    inside your own op.
+
     The service account that is used to run this job should have the following RBAC permissions:
 
     .. literalinclude:: ../../../../../../examples/docs_snippets/docs_snippets/deploying/kubernetes/k8s_job_op_rbac.yaml
